default_app_config = "structures.apps.StructuresConfig"

__version__ = "1.3.4"
__title__ = "Structures"
